package App::chartimes ;  
our $VERSION = '0.031' ; 
our $DATE = '2024-03-16T00:24+09:00' ; 

=encoding utf8

=head1 NAME

App::chartimes - 各文字iをj個持つ行が、入力全体に何行発生したか行列状に表示する。jの意味を、同じiが最長何回連続して発生したか意味を変えるオプションもある。

=head1 SYNOPSIS

This module provides a Unix-like command `F<chartimes>'. 

=head1 DESCRIPTION

=head1 SEE ALSO

chartimes --help
man chartimes
perldoc chartimes

=cut

1 ;
